@@ -11,17 +11,20 @@
 # Author: John Egan <john@shopkick.com>
 
 from flawless.lib.data_structures import ProxyContainerMethodsMetaClass
+from flawless.lib.data_structures.storage import StorageInterface
 
 
-class PersistentDictionaryStub(object):
+class StorageStub(object):
+
     __metaclass__ = ProxyContainerMethodsMetaClass
     _proxyfunc_ = lambda attr, self, *args, **kwargs: getattr(self.dict, attr)(*args, **kwargs)
 
-    def __init__(self, file_path):
-        self.file_path = file_path
+    def __init__(self, week_prefix):
+        self.week_prefix = week_prefix
+        self.dict = dict()
 
     def open(self):
-        self.dict = dict()
+        pass
 
     def sync(self):
         pass
@@ -29,5 +32,7 @@ class PersistentDictionaryStub(object):
     def close(self):
         pass
 
-    def get_path(self):
-        return self.file_path
+    def iteritems(self):
+        return self.dict.iteritems()
+
+StorageInterface.register(StorageStub)
